==> vpn-user-portal-3.6.4.tgz: vpn-user-portal/locale/es-ES.php <==
<?php

declare(strict_types=1);

/*
 * eduVPN - End-user friendly VPN.
 *
 * Copyright: 2014-2023, The Commons Conservancy eduVPN Programme
 * SPDX-License-Identifier: AGPL-3.0+
 */

return [
    '#Active (Max #Available) Connections' => '#Conexiones activas (Máx #disponibles)',
    '#Connections in 5 minute intervals' => '#Conexiones en intervalos de 5 minutos',
    '#Unique Guest Users' => '#Usuarios invitados únicos',
    '#Unique Users' => '#Usuarios únicos',
    '#Unique users and max #connections per day' => '#Usuarios únicos y máx #conexiones por día',
    'ACL Permission List' => 'Lista de permisos ACL',
    'Account' => 'Cuenta',
    'Active' => 'Activo',
    'Active Configurations' => 'Configuraciones activas',
    'Aggregated' => 'Agregado',
    'All' => 'Todos',
    'An application attempts to establish a VPN connection.' => 'Una aplicación intenta establecer una conexión VPN.',
    'An error occurred.' => 'Se ha producido un error.',
    'Application Usage' => 'Uso de la aplicación',
    'Approve' => 'Aprobar',
    'Approve Application' => 'Aprobar aplicación',
    'Authentication Data' => 'Datos de autenticación',
    'Authorized Applications' => 'Aplicaciones autorizadas',
    'Authorized On' => 'Autorizado el',
    'Available Profiles' => 'Perfiles disponibles',
    'Block LAN' => 'Bloquear LAN',
    'CA' => 'Autoridad certificadora',
    'CPU Usage:' => 'Uso de CPU:',
    'Change Password' => 'Cambiar contraseña',
    'Configurations' => 'Configuraciones',
    'Confirm' => 'Confirmar',
    'Connected' => 'Conectado',
    'Connections' => 'Conexiones',
    'Created On' => 'Creado el',
    'Current Password' => 'Contraseña actual',
    'Current Password not correct!' => '¡La contraseña actual no es correcta!',
    'Currently there are no clients connected to this profile.' => 'Actualmente no hay clientes conectados a este perfil.',
    'DNS Search Domain(s)' => 'Dominio(s) de búsqueda DNS',
    'DNS Server(s)' => 'Servidor(es) DNS',
    'Danger Zone' => 'Zona de peligro',
    'Date/Time' => 'Fecha/Hora',
    'Default Gateway' => 'Puerta de enlace predeterminada',
    'Delete' => 'Eliminar',
    'Delete Account' => 'Eliminar cuenta',
    'Delete Account Data' => 'Eliminar datos de cuenta',
    'Disable Account' => 'Deshabilitar cuenta',
    'Disabled' => 'Deshabilitada',
    'Disconnected' => 'Desconectado',
    'Distribution of unique users over the VPN applications.' => 'Distribución de usuarios únicos en las aplicaciones VPN.',
    'Download' => 'Descargar',
    'Downloading VPN configurations is not allowed. Please use a VPN application.' => 'No se permite la descarga de configuraciones VPN. Por favor, usa una aplicación VPN.',
    'Enable Account' => 'Habilitar cuenta',
    //'Error' => '',
    'Excluded Route(s)' => 'Ruta(s) excluidas',
    'Expires On' => 'Expira el',
    'Export (CSV)' => 'Exportar (CSV)',
    'Find the user identifier that used an IPv4 or IPv6 address at a particular point in time.' => 'Encuentra el identificador de usuario que utilizó una dirección IPv4 o IPv6 en un momento determinado.',
    'Fingerprint' => 'Huella digital',
    'Here you can change the password for your account.' => 'Aquí puedes cambiar la contraseña de tu cuenta.',
    'Home' => 'Inicio',
    'Hostname' => 'Nombre del equipo',
    'IP Address' => 'Dirección IP',
    //'IPs' => '',
    'IPv4 Prefix' => 'Prefijo IPv4',
    'IPv6 Prefix' => 'Prefijo IPv6',
    'Import or copy/paste this configuration to your WireGuard application.' => 'Importa o copia/pega esta configuración en tu aplicación WireGuard.',
    'Info' => 'Información',
    'Issues' => 'Problemas',
    'Live' => 'En vivo',
    'Log' => 'Registro',
    //'MTU' => '',
    'Max #Connections' => 'Máx #Conexiones',
    'More' => 'Más',
    'N/A' => 'N/D',
    'Name' => 'Nombre',
    'New Configuration' => 'Nueva configuración',
    'New Password' => 'Nueva contraseña',
    'New Password (confirm)' => 'Nueva contraseña (confirmar)',
    'New Password and New Password (confirm) MUST match!' => '¡La nueva contraseña y Nueva contraseña (confirmar) DEBEN coincidir!',
    'No Permission(s)' => 'Sin permisos',
    'No VPN profiles are available for your account.' => 'No hay perfiles VPN disponibles para tu cuenta.',
    'Node URL' => 'URL del nodo',
    'Node(s)' => 'Nodo(s)',
    //'OAuth' => '',
    'Obtain a new VPN configuration file for use in your VPN client.' => 'Obtén un nuevo archivo de configuración VPN para usar en tu cliente VPN.',
    'Offered Ports' => 'Puertos ofrecidos',
    'Offline' => 'Desconectado',
    'Online' => 'En línea',
    'Only approve this when you are trying to establish a VPN connection with this application!' => '¡Aprueba esto solo cuando estés intentando establecer una conexión VPN con esta aplicación!',
    //'OpenVPN' => '',
    'OpenVPN (Prefer TCP)' => 'OpenVPN (Preferir TCP)',
    'OpenVPN (Prefer UDP)' => 'OpenVPN (Preferir UDP)',
    'OpenVPN Server Log' => 'Registro del servidor OpenVPN',
    'Password' => 'Contraseña',
    'Permissions' => 'Permisos',
    'Please sign in with your username and password.' => 'Por favor, inicia sesión con tu nombre de usuario y contraseña.',
    'Port' => 'Puerto',
    'Ports' => 'Puertos',
    'Preferred Protocol' => 'Protocolo preferido',
    'Profile' => 'Perfil',
    'Profile ID' => 'ID de perfil',
    'Profile Usage' => 'Uso del perfil',
    'Profile(s)' => 'Perfil(es)',
    'Public Key' => 'Clave pública',
    'Refresh' => 'Actualizar',
    'Results' => 'Resultados',
    'Revoke' => 'Revocar',
    'Route(s)' => 'Ruta(s)',
    'Search' => 'Buscar',
    'Select a profile and choose a name, e.g. "Phone".' => 'Selecciona un perfil y elige un nombre, por ejemplo, "Teléfono".',
    'Server' => 'Servidor',
    'Sign In' => 'Iniciar sesión',
    'Sign Out' => 'Cerrar sesión',
    //'Sorted by "Authorized On", most recent authorization first.' => '',
    'Stats' => 'Estadísticas',
    'The <em>Date/Time</em> MUST be in UTC.' => 'La <em>Fecha/Hora</em> DEBE estar en UTC.',
    'The <em>Date/Time</em> field accepts dates of the format <code>Y-m-d H:i:s</code>, e.g. <code>2019-01-01 08:00:00</code>.' => 'El campo <em>Fecha/Hora</em> acepta fechas en el formato <code>Y-m-d H:i:s</code>, por ejemplo <code>2019-01-01 08:00:00</code>.',
    'The credentials you provided were not correct.' => 'Las credenciales proporcionadas no son correctas.',
    'The list of applications you authorized to create a VPN connection.' => 'La lista de aplicaciones que autorizaste para crear una conexión VPN.',
    'The maximum number of simultaneously connected VPN clients at a particular moment in time over the last week' => 'El número máximo de clientes VPN conectados simultáneamente en un momento determinado durante la última semana',
    'The most recent VPN connections with this account.' => 'Las conexiones VPN más recientes con esta cuenta.',
    'The number of currently connected VPN clients, and the maximum possible number of connected VPN clients based on available IP-space for this profile.' => 'El número de clientes VPN conectados actualmente y el número máximo posible de clientes VPN conectados según el espacio de IP disponible para este perfil.',
    'The number of unique guest users connecting to the VPN service in the last week' => 'El número de usuarios invitados únicos que se conectan al servicio VPN en la última semana',
    'The number of unique users connecting to the VPN service in the last week' => 'El número de usuarios únicos que se conectan al servicio VPN en la última semana',
    'The table below shows the per profile VPN usage over the last week.' => 'La tabla siguiente muestra el uso de VPN por perfil durante la última semana.',
    'There are no results matching your criteria.' => 'No hay resultados que coincidan con tu criterio.',
    'This server uses an external authentication source. Deleting the account data will not prevent the user from authenticating (again)!' => 'Este servidor utiliza una fuente de autenticación externa. ¡Eliminar los datos de la cuenta no impedirá que el usuario se autentique (de nuevo)!',
    'This user does not have any active configurations.' => 'Este usuario no tiene ninguna configuración activa.',
    'This user does not have any connections.' => 'Este usuario no tiene ninguna conexión.',
    'To prevent malicious applications from secretly establishing a VPN connection on your behalf, you have to explicitly approve this application first.' => 'Para evitar que aplicaciones maliciosas establezcan una conexión VPN en secreto a tu nombre, debes aprobar explícitamente esta aplicación primero.',
    'Use the WireGuard app on your mobile device to scan this QR code.' => 'Utiliza la aplicación WireGuard en tu dispositivo móvil para escanear este código QR.',
    'User ID' => 'ID de usuario',
    'Username' => 'Nombre de usuario',
    'Users' => 'Usuarios',
    'VPN Portal' => 'Portal VPN',
    'Version' => 'Versión',
    'Welcome to this VPN service!' => '¡Bienvenido a este servicio VPN!',
    'Why is this necessary?' => '¿Por qué es necesario esto?',
    //'WireGuard' => '',
    //'WireGuard (TCP)' => '',
    //'WireGuard (UDP)' => '',
    'WireGuard Configuration' => 'Configuración de WireGuard',
    'You can download the detailed VPN usage statistics below.' => 'Puedes descargar las estadísticas detalladas de uso de VPN a continuación.',
    'You cannot manage your own user account.' => 'No puedes gestionar tu propia cuenta de usuario.',
    'You have reached the maximum number of allowed active VPN configurations. Delete some first.' => 'Has alcanzado el número máximo de configuraciones VPN activas permitidas. Elimina algunas primero.',
    'Your account does not have access to any VPN profile.' => 'Tu cuenta no tiene acceso a ningún perfil VPN.',
    'Your new configuration will expire on %expiryDate%. Come back here to obtain a new configuration after expiry!' => 'Tu nueva configuración caducará el %expiryDate%. ¡Vuelve aquí para obtener una nueva configuración después de la caducidad!',
];

==> vpn-user-portal-3.7.2.tgz: vpn-user-portal/locale/es-ES.php <==
<?php

declare(strict_types=1);

/*
 * eduVPN - End-user friendly VPN.
 *
 * Copyright: 2014-2023, The Commons Conservancy eduVPN Programme
 * SPDX-License-Identifier: AGPL-3.0+
 */

return [
    '#Active (Max #Available) Connections' => '#Conexiones activas (Máx #disponibles)',
    '#Connections in 5 minute intervals' => '#Conexiones en intervalos de 5 minutos',
    '#Unique Guest Users' => '#Usuarios invitados únicos',
    '#Unique Users' => '#Usuarios únicos',
    '#Unique users and max #connections per day' => '#Usuarios únicos y máx #conexiones por día',
    'ACL Permission List' => 'Lista de permisos ACL',
    'Account' => 'Cuenta',
    'Active' => 'Activo',
    'Active Configurations' => 'Configuraciones activas',
    'Aggregated' => 'Agregado',
    'All' => 'Todos',
    'An application attempts to establish a VPN connection.' => 'Una aplicación intenta establecer una conexión VPN.',
    'An error occurred.' => 'Se ha producido un error.',
    'Application Usage' => 'Uso de la aplicación',
    'Approve' => 'Aprobar',
    'Approve Application' => 'Aprobar aplicación',
    'Authentication Data' => 'Datos de autenticación',
    'Authorized Applications' => 'Aplicaciones autorizadas',
    'Authorized On' => 'Autorizado el',
    'Available Profiles' => 'Perfiles disponibles',
    'Block LAN' => 'Bloquear LAN',
    'CA' => 'Autoridad certificadora',
    'CPU Usage:' => 'Uso de CPU:',
    'Change Password' => 'Cambiar contraseña',
    'Configurations' => 'Configuraciones',
    'Confirm' => 'Confirmar',
    'Connected' => 'Conectado',
    'Connections' => 'Conexiones',
    'Created On' => 'Creado el',
    'Current Password' => 'Contraseña actual',
    'Current Password not correct!' => '¡La contraseña actual no es correcta!',
    'Currently there are no clients connected to this profile.' => 'Actualmente no hay clientes conectados a este perfil.',
    'DNS Search Domain(s)' => 'Dominio(s) de búsqueda DNS',
    'DNS Server(s)' => 'Servidor(es) DNS',
    'Danger Zone' => 'Zona de peligro',
    //'Database' => '',
    'Date/Time' => 'Fecha/Hora',
    'Default Gateway' => 'Puerta de enlace predeterminada',
    'Delete' => 'Eliminar',
    'Delete Account' => 'Eliminar cuenta',
    'Delete Account Data' => 'Eliminar datos de cuenta',
    'Disable Account' => 'Deshabilitar cuenta',
    'Disabled' => 'Deshabilitada',
    'Disconnected' => 'Desconectado',
    'Distribution of unique users over the VPN applications.' => 'Distribución de usuarios únicos en las aplicaciones VPN.',
    'Download' => 'Descargar',
    'Downloading VPN configurations is not allowed. Please use a VPN application.' => 'No se permite la descarga de configuraciones VPN. Por favor, usa una aplicación VPN.',
    //'Driver' => '',
    'Enable Account' => 'Habilitar cuenta',
    //'Error' => '',
    'Excluded Route(s)' => 'Ruta(s) excluidas',
    'Expires On' => 'Expira el',
    'Export (CSV)' => 'Exportar (CSV)',
    'Find the user identifier that used an IPv4 or IPv6 address at a particular point in time.' => 'Encuentra el identificador de usuario que utilizó una dirección IPv4 o IPv6 en un momento determinado.',
    'Fingerprint' => 'Huella digital',
    'Here you can change the password for your account.' => 'Aquí puedes cambiar la contraseña de tu cuenta.',
    'Home' => 'Inicio',
    'Hostname' => 'Nombre del equipo',
    'IP Address' => 'Dirección IP',
    //'IPs' => '',
    'IPv4 Prefix' => 'Prefijo IPv4',
    'IPv6 Prefix' => 'Prefijo IPv6',
    'Import or copy/paste this configuration to your WireGuard application.' => 'Importa o copia/pega esta configuración en tu aplicación WireGuard.',
    'Info' => 'Información',
    'Issues' => 'Problemas',
    //'Last Used' => '',
    'Live' => 'En vivo',
    'Log' => 'Registro',
    //'MTU' => '',
    'Max #Connections' => 'Máx #Conexiones',
    'More' => 'Más',
    'N/A' => 'N/D',
    'Name' => 'Nombre',
    'New Configuration' => 'Nueva configuración',
    'New Password' => 'Nueva contraseña',
    'New Password (confirm)' => 'Nueva contraseña (confirmar)',
    'New Password and New Password (confirm) MUST match!' => '¡La nueva contraseña y Nueva contraseña (confirmar) DEBEN coincidir!',
    'No Permission(s)' => 'Sin permisos',
    'No VPN profiles are available for your account.' => 'No hay perfiles VPN disponibles para tu cuenta.',
    'Node URL' => 'URL del nodo',
    'Node(s)' => 'Nodo(s)',
    //'OAuth' => '',
    'Obtain a new VPN configuration file for use in your VPN client.' => 'Obtén un nuevo archivo de configuración VPN para usar en tu cliente VPN.',
    'Offered Ports' => 'Puertos ofrecidos',
    'Offline' => 'Desconectado',
    'Online' => 'En línea',
    'Only approve this when you are trying to establish a VPN connection with this application!' => '¡Aprueba esto solo cuando estés intentando establecer una conexión VPN con esta aplicación!',
    //'OpenVPN' => '',
    'OpenVPN (Prefer TCP)' => 'OpenVPN (Preferir TCP)',
    'OpenVPN (Prefer UDP)' => 'OpenVPN (Preferir UDP)',
    'OpenVPN Server Log' => 'Registro del servidor OpenVPN',
    'Password' => 'Contraseña',
    'Permissions' => 'Permisos',
    'Please sign in with your username and password.' => 'Por favor, inicia sesión con tu nombre de usuario y contraseña.',
    'Port' => 'Puerto',
    'Ports' => 'Puertos',
    'Preferred Protocol' => 'Protocolo preferido',
    'Profile' => 'Perfil',
    'Profile ID' => 'ID de perfil',
    'Profile Usage' => 'Uso del perfil',
    'Profile(s)' => 'Perfil(es)',
    //'Proxy URL' => '',
    'Public Key' => 'Clave pública',
    'Refresh' => 'Actualizar',
    'Results' => 'Resultados',
    'Revoke' => 'Revocar',
    'Route(s)' => 'Ruta(s)',
    'Search' => 'Buscar',
    'Select a profile and choose a name, e.g. "Phone".' => 'Selecciona un perfil y elige un nombre, por ejemplo, "Teléfono".',
    'Server' => 'Servidor',
    'Sign In' => 'Iniciar sesión',
    'Sign Out' => 'Cerrar sesión',
    //'Sorted by "Last Used", most recently used first.' => '',
    'Stats' => 'Estadísticas',
    'The <em>Date/Time</em> MUST be in UTC.' => 'La <em>Fecha/Hora</em> DEBE estar en UTC.',
    'The <em>Date/Time</em> field accepts dates of the format <code>Y-m-d H:i:s</code>, e.g. <code>2019-01-01 08:00:00</code>.' => 'El campo <em>Fecha/Hora</em> acepta fechas en el formato <code>Y-m-d H:i:s</code>, por ejemplo <code>2019-01-01 08:00:00</code>.',
    'The credentials you provided were not correct.' => 'Las credenciales proporcionadas no son correctas.',
    'The list of applications you authorized to create a VPN connection.' => 'La lista de aplicaciones que autorizaste para crear una conexión VPN.',
    'The maximum number of simultaneously connected VPN clients at a particular moment in time over the last week' => 'El número máximo de clientes VPN conectados simultáneamente en un momento determinado durante la última semana',
    'The most recent VPN connections with this account.' => 'Las conexiones VPN más recientes con esta cuenta.',
    'The number of currently connected VPN clients, and the maximum possible number of connected VPN clients based on available IP-space for this profile.' => 'El número de clientes VPN conectados actualmente y el número máximo posible de clientes VPN conectados según el espacio de IP disponible para este perfil.',
    'The number of unique guest users connecting to the VPN service in the last week' => 'El número de usuarios invitados únicos que se conectan al servicio VPN en la última semana',
    'The number of unique users connecting to the VPN service in the last week' => 'El número de usuarios únicos que se conectan al servicio VPN en la última semana',
    'The table below shows the per profile VPN usage over the last week.' => 'La tabla siguiente muestra el uso de VPN por perfil durante la última semana.',
    'There are no results matching your criteria.' => 'No hay resultados que coincidan con tu criterio.',
    'This server uses an external authentication source. Deleting the account data will not prevent the user from authenticating (again)!' => 'Este servidor utiliza una fuente de autenticación externa. ¡Eliminar los datos de la cuenta no impedirá que el usuario se autentique (de nuevo)!',
    'This user does not have any active configurations.' => 'Este usuario no tiene ninguna configuración activa.',
    //'This user does not have any authorized applications.' => '',
    'This user does not have any connections.' => 'Este usuario no tiene ninguna conexión.',
    'To prevent malicious applications from secretly establishing a VPN connection on your behalf, you have to explicitly approve this application first.' => 'Para evitar que aplicaciones maliciosas establezcan una conexión VPN en secreto a tu nombre, debes aprobar explícitamente esta aplicación primero.',
    'Use the WireGuard app on your mobile device to scan this QR code.' => 'Utiliza la aplicación WireGuard en tu dispositivo móvil para escanear este código QR.',
    'User ID' => 'ID de usuario',
    'Username' => 'Nombre de usuario',
    'Users' => 'Usuarios',
    'VPN Portal' => 'Portal VPN',
    'Version' => 'Versión',
    'Welcome to this VPN service!' => '¡Bienvenido a este servicio VPN!',
    'Why is this necessary?' => '¿Por qué es necesario esto?',
    //'WireGuard' => '',
    //'WireGuard (TCP)' => '',
    //'WireGuard (UDP)' => '',
    'WireGuard Configuration' => 'Configuración de WireGuard',
    'You can download the detailed VPN usage statistics below.' => 'Puedes descargar las estadísticas detalladas de uso de VPN a continuación.',
    'You cannot manage your own user account.' => 'No puedes gestionar tu propia cuenta de usuario.',
    'You have reached the maximum number of allowed active VPN configurations. Delete some first.' => 'Has alcanzado el número máximo de configuraciones VPN activas permitidas. Elimina algunas primero.',
    'Your account does not have access to any VPN profile.' => 'Tu cuenta no tiene acceso a ningún perfil VPN.',
    'Your new configuration will expire on %expiryDate%. Come back here to obtain a new configuration after expiry!' => 'Tu nueva configuración caducará el %expiryDate%. ¡Vuelve aquí para obtener una nueva configuración después de la caducidad!',
];
